@@ -1,7 +1,7 @@
 /*
 	id3: ID3v2.3 and ID3v2.4 parsing (a relevant subset)
 
-	copyright 2006-2020 by the mpg123 project - free software under the terms of the LGPL 2.1
+	copyright 2006-2023 by the mpg123 project - free software under the terms of the LGPL 2.1
 	see COPYING and AUTHORS files in distribution or http://mpg123.org
 	initially written by Thomas Orgis
 
@@ -85,7 +85,7 @@
 
 #include "mpg123lib_intern.h"
 #include "id3.h"
-#include "debug.h"
+#include "../common/debug.h"
 
 #ifndef NO_ID3V2 /* Only the main parsing routine will always be there. */
 
@@ -126,7 +126,7 @@ static void null_id3_links(mpg123_handle *fr)
 	fr->id3v2.comment = NULL;
 }
 
-void init_id3(mpg123_handle *fr)
+void INT123_init_id3(mpg123_handle *fr)
 {
 	fr->id3v2.version = 0; /* nothing there */
 	null_id3_links(fr);
@@ -241,7 +241,7 @@ static mpg123_text *add_id3_text( mpg123_text **list, size_t *size
 	}
 	mdebug("add_id3_text: append to list of %zu", *size);
 	// Nothing found, add new one.
-	mpg123_text *x = safe_realloc(*list, sizeof(mpg123_text)*(*size+1));
+	mpg123_text *x = INT123_safe_realloc(*list, sizeof(mpg123_text)*(*size+1));
 	if(x == NULL) return NULL; /* bad */
 
 	*list  = x;
@@ -269,7 +269,7 @@ static mpg123_picture *add_id3_picture(mpg123_picture **list, size_t *size, char
 			return entry;
 	}
 	// Append a new one.
-	mpg123_picture *x = safe_realloc(*list, sizeof(mpg123_picture)*(*size+1));
+	mpg123_picture *x = INT123_safe_realloc(*list, sizeof(mpg123_picture)*(*size+1));
 	if(x == NULL) return NULL; /* bad */
 
 	*list  = x;
@@ -281,7 +281,7 @@ static mpg123_picture *add_id3_picture(mpg123_picture **list, size_t *size, char
 
 /* OK, back to the higher level functions. */
 
-void exit_id3(mpg123_handle *fr)
+void INT123_exit_id3(mpg123_handle *fr)
 {
 	free_picture(fr);
 	free_comment(fr);
@@ -289,14 +289,14 @@ void exit_id3(mpg123_handle *fr)
 	free_text(fr);
 }
 
-void reset_id3(mpg123_handle *fr)
+void INT123_reset_id3(mpg123_handle *fr)
 {
-	exit_id3(fr);
-	init_id3(fr);
+	INT123_exit_id3(fr);
+	INT123_init_id3(fr);
 }
 
 /* Set the id3v2.artist id3v2.title ... links to elements of the array. */
-void id3_link(mpg123_handle *fr)
+void INT123_id3_link(mpg123_handle *fr)
 {
 	size_t i;
 	mpg123_id3v2 *v2 = &fr->id3v2;
@@ -330,9 +330,9 @@ void id3_link(mpg123_handle *fr)
 	Since we can overwrite strings with ID3 update frames, don't free
 	memory, just grow strings.
 */
-static void store_id3_text(mpg123_string *sb, unsigned char *source, size_t source_size, const int noquiet, const int notranslate)
+static void store_id3_text(mpg123_string *sb, unsigned char encoding, unsigned char *source
+,	size_t source_size, const int noquiet, const int notranslate)
 {
-	unsigned char encoding;
 	if(sb) // Always overwrite, even with nothing.
 		sb->fill = 0;
 	if(!source_size)
@@ -345,25 +345,25 @@ static void store_id3_text(mpg123_string *sb, unsigned char *source, size_t sour
 	if(notranslate)
 	{
 		/* Future: Add a path for ID3 errors. */
-		if(!mpg123_grow_string(sb, source_size))
+		if(!mpg123_grow_string(sb, source_size+1))
 		{
 			if(noquiet) error("Cannot resize target string, out of memory?");
 			return;
 		}
-		memcpy(sb->p, source, source_size);
-		sb->fill = source_size;
-		debug1("stored undecoded ID3 text of size %"SIZE_P, (size_p)source_size);
+		sb->p[0] = (char)encoding;
+		memcpy(sb->p+1, source, source_size);
+		sb->fill = source_size+1;
+		debug1("stored undecoded ID3 text of size %zu", source_size+1);
 		return;
 	}
 
-	encoding = source[0];
 	if(encoding > mpg123_id3_enc_max)
 	{
 		if(noquiet)
 			error1("Unknown text encoding %u, I take no chances, sorry!", encoding);
 		return;
 	}
-	id3_to_utf8(sb, encoding, source+1, source_size-1, noquiet);
+	INT123_id3_to_utf8(sb, encoding, source, source_size, noquiet);
 
 	if(sb->fill) debug1("UTF-8 string (the first one): %s", sb->p);
 	else if(noquiet) error("unable to convert string to UTF-8 (out of memory, junk input?)!");
@@ -371,7 +371,7 @@ static void store_id3_text(mpg123_string *sb, unsigned char *source, size_t sour
 
 /* On error, sb->size is 0. */
 /* Also, encoding has been checked already! */
-void id3_to_utf8(mpg123_string *sb, unsigned char encoding, const unsigned char *source, size_t source_size, int noquiet)
+void INT123_id3_to_utf8(mpg123_string *sb, unsigned char encoding, const unsigned char *source, size_t source_size, int noquiet)
 {
 	unsigned int bwidth;
 	if(sb)
@@ -403,9 +403,12 @@ static unsigned char *next_text(unsigned char* prev, unsigned char encoding, siz
 	unsigned char *text = prev;
 	size_t width = encoding_widths[encoding];
 
+	if(limit > PTRDIFF_MAX)
+		return NULL;
+
 	/* So I go lengths to find zero or double zero...
 	   Remember bug 2834636: Only check for aligned NULLs! */
-	while(text-prev < (ssize_t)limit)
+	while(text-prev < (ptrdiff_t)limit)
 	{
 		if(text[0] == 0)
 		{
@@ -446,6 +449,11 @@ static void process_text(mpg123_handle *fr, unsigned char *realdata, size_t real
 {
 	/* Text encoding          $xx */
 	/* The text (encoded) ... */
+	if(realsize < 1)
+	{
+		if(NOQUIET) error("Not even an encoding byte?");
+		return;
+	}
 	mpg123_text *t = add_text(fr, id);
 	if(VERBOSE4) fprintf(stderr, "Note: Storing text from %s encoding\n", enc_name(realdata[0]));
 	if(t == NULL)
@@ -457,7 +465,8 @@ static void process_text(mpg123_handle *fr, unsigned char *realdata, size_t real
 	?	(char[5]) { t->id[0], t->id[1], t->id[2], t->id[3], 0 }
 	:	"(nil)" );
 	memcpy(t->id, id, 4);
-	store_id3_text(&t->text, realdata, realsize, NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT);
+	store_id3_text( &t->text, realdata[0], realdata+1, realsize-1
+	,	NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT );
 	if(VERBOSE4) // Do not print unsanitized text to terminals!
 		fprintf(stderr, "Note: ID3v2 %c%c%c%c text frame stored\n", id[0], id[1], id[2], id[3]);
 }
@@ -494,7 +503,7 @@ static void process_picture(mpg123_handle *fr, unsigned char *realdata, size_t r
 			error("Unable to get mime type for picture; skipping picture.");
 		return;
 	}
-	id3_to_utf8(&mime, 0, realdata, workpoint - realdata, NOQUIET);
+	INT123_id3_to_utf8(&mime, 0, realdata, workpoint - realdata, NOQUIET);
 	realsize -= workpoint - realdata;
 	realdata = workpoint;
 	/* get picture type */
@@ -509,7 +518,7 @@ static void process_picture(mpg123_handle *fr, unsigned char *realdata, size_t r
 		mpg123_free_string(&mime);
 		return;
 	}
-	id3_to_utf8(&description, encoding, realdata, workpoint - realdata, NOQUIET);
+	INT123_id3_to_utf8(&description, encoding, realdata, workpoint - realdata, NOQUIET);
 	realsize -= workpoint - realdata;
 	if(realsize)
 		image_data = (unsigned char*)malloc(realsize);
@@ -564,7 +573,7 @@ static void process_comment(mpg123_handle *fr, enum frame_types tt, unsigned cha
 
 	if(realsize < (size_t)(descr-realdata))
 	{
-		if(NOQUIET) error1("Invalid frame size of %"SIZE_P" (too small for anything).", (size_p)realsize);
+		if(NOQUIET) error1("Invalid frame size of %zu (too small for anything).", realsize);
 		return;
 	}
 	if(encoding > mpg123_id3_enc_max)
@@ -574,8 +583,6 @@ static void process_comment(mpg123_handle *fr, enum frame_types tt, unsigned cha
 		return;
 	}
 	memcpy(lang, realdata+1, 3);
-	/* Now I can abuse a byte from lang for the encoding. */
-	descr[-1] = encoding;
 	/* Be careful with finding the end of description, I have to honor encoding here. */
 	text = next_text(descr, encoding, realsize-(descr-realdata));
 	if(text == NULL)
@@ -588,14 +595,14 @@ static void process_comment(mpg123_handle *fr, enum frame_types tt, unsigned cha
 		mpg123_string description;
 		mpg123_init_string(&description);
 		// Store the text, with desired encoding, but for comments always a local copy in UTF-8.
-		store_id3_text( &description, descr-1, text-descr+1
+		store_id3_text( &description, encoding, descr, text-descr
 		,	NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT );
 		if(tt == comment)
-			store_id3_text( &localcom.description, descr-1, text-descr+1
+			store_id3_text( &localcom.description, encoding, descr, text-descr
 			,	NOQUIET, 0 );
 		if(VERBOSE4)
 			fprintf( stderr, "Note: Storing comment from %s encoding\n"
-			,	enc_name(realdata[0]) );
+			,	enc_name(encoding) );
 		xcom = tt == uslt
 		?	add_uslt(fr, lang, &description)
 		:	add_comment(fr, lang, &description);
@@ -613,14 +620,14 @@ static void process_comment(mpg123_handle *fr, enum frame_types tt, unsigned cha
 		mpg123_move_string(&description, &xcom->description);
 	}
 
-	text[-1] = encoding; /* Byte abusal for encoding... */
-	store_id3_text(&xcom->text, text-1, realsize+1-(text-realdata), NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT);
+	store_id3_text( &xcom->text, encoding, text, realsize-(text-realdata)
+	,	NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT );
 	/* Remember: I will probably decode the above (again) for rva comment checking. So no messing around, please. */
 
 	if(VERBOSE4) /* Do _not_ print the verbatim text: The encoding might be funny! */
 	{
-		fprintf(stderr, "Note: ID3 comm/uslt desc of length %"SIZE_P".\n", (size_p)xcom->description.fill);
-		fprintf(stderr, "Note: ID3 comm/uslt text of length %"SIZE_P".\n", (size_p)xcom->text.fill);
+		fprintf(stderr, "Note: ID3 comm/uslt desc of length %zu.\n", xcom->description.fill);
+		fprintf(stderr, "Note: ID3 comm/uslt text of length %zu.\n", xcom->text.fill);
 	}
 	/* Look out for RVA info only when we really deal with a straight comment. */
 	if(tt == comment && localcom.description.fill > 0)
@@ -638,7 +645,8 @@ static void process_comment(mpg123_handle *fr, enum frame_types tt, unsigned cha
 		if((rva_mode > -1) && (fr->rva.level[rva_mode] <= rva_level))
 		{
 			/* Only translate the contents in here where we really need them. */
-			store_id3_text(&localcom.text, text-1, realsize+1-(text-realdata), NOQUIET, 0);
+			store_id3_text( &localcom.text, encoding, text, realsize-(text-realdata)
+			,	NOQUIET, 0 );
 			if(localcom.text.fill > 0)
 			{
 				fr->rva.gain[rva_mode] = (float) atof(localcom.text.p);
@@ -686,7 +694,7 @@ static void process_extra(mpg123_handle *fr, unsigned char* realdata, size_t rea
 		mpg123_init_string(&description);
 		/* The outside storage gets reencoded to UTF-8 only if not requested otherwise.
 		   Remember that we really need the -1 here to hand in the encoding byte!*/
-		store_id3_text( &description, descr-1, text-descr+1
+		store_id3_text( &description, encoding, descr, text-descr
 		,	NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT );
 		xex = add_extra(fr, &description);
 		if(xex)
@@ -703,10 +711,10 @@ static void process_extra(mpg123_handle *fr, unsigned char* realdata, size_t rea
 	init_mpg123_text(&localex); /* For our local copy. */
 
 	/* Our local copy is always stored in UTF-8! */
-	store_id3_text(&localex.description, descr-1, text-descr+1, NOQUIET, 0);
+	store_id3_text(&localex.description, encoding, descr, text-descr, NOQUIET, 0);
 	/* At first, only store the outside copy of the payload. We may not need the local copy. */
-	text[-1] = encoding;
-	store_id3_text(&xex->text, text-1, realsize-(text-realdata)+1, NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT);
+	store_id3_text( &xex->text, encoding, text, realsize-(text-realdata)
+	,	NOQUIET, fr->p.flags & MPG123_PLAIN_ID3TEXT );
 
 	/* Now check if we would like to interpret this extra info for RVA. */
 	if(localex.description.fill > 0)
@@ -734,7 +742,8 @@ static void process_extra(mpg123_handle *fr, unsigned char* realdata, size_t rea
 		if((rva_mode > -1) && (fr->rva.level[rva_mode] <= rva_level))
 		{
 			/* Now we need the translated copy of the data. */
-			store_id3_text(&localex.text, text-1, realsize-(text-realdata)+1, NOQUIET, 0);
+			store_id3_text( &localex.text, encoding, text, realsize-(text-realdata)
+			,	NOQUIET, 0 );
 			if(localex.text.fill > 0)
 			{
 				if(is_peak)
@@ -791,11 +800,11 @@ static int promote_framename(mpg123_handle *fr, char *id) /* fr because of VERBO
 
 #endif /* NO_ID3V2 */
 
-int store_id3v2( mpg123_handle *fr
+static int store_id3v2( mpg123_handle *fr
 ,	unsigned long first4bytes, unsigned char buf[6], unsigned long length )
 {
 	int ret = 1;
-	off_t ret2;
+	int64_t ret2;
 	unsigned long fullen = 10+length;
 	if(fr->id3v2_raw)
 		free(fr->id3v2_raw);
@@ -842,7 +851,7 @@ int store_id3v2( mpg123_handle *fr
 	          1: good, (possibly) new tag info
 	         <0: reader error (may need more data feed, try again)
 */
-int parse_new_id3(mpg123_handle *fr, unsigned long first4bytes)
+int INT123_parse_new_id3(mpg123_handle *fr, unsigned long first4bytes)
 {
 	#define UNSYNC_FLAG 128
 	#define EXTHEAD_FLAG 64  /* ID3v2.3+ */
@@ -855,7 +864,7 @@ int parse_new_id3(mpg123_handle *fr, unsigned long first4bytes)
 	unsigned long length=0;
 	unsigned char flags = 0;
 	int ret = 1;
-	off_t ret2;
+	int64_t ret2;
 	int storetag = 0;
 	unsigned int footlen = 0;
 #ifndef NO_ID3V2
@@ -961,7 +970,7 @@ int parse_new_id3(mpg123_handle *fr, unsigned long first4bytes)
 	{
 		if(VERBOSE3)
 			fprintf(stderr, "Note: skipped tag clearing possibly existing ID3v2 data");
-		reset_id3(fr); // Old data is invalid.
+		INT123_reset_id3(fr); // Old data is invalid.
 #endif
 		if(!storetag && (ret2=fr->rd->skip_bytes(fr,length+footlen))<0)
 			ret=ret2;
@@ -1025,7 +1034,7 @@ int parse_new_id3(mpg123_handle *fr, unsigned long first4bytes)
 			{
 				if(VERBOSE3)
 					fprintf(stderr, "Note: non-update tag replacing existing ID3v2 data\n");
-				reset_id3(fr);
+				INT123_reset_id3(fr);
 			}
 			if(ret > 0)
 			{
@@ -1274,13 +1283,13 @@ int parse_new_id3(mpg123_handle *fr, unsigned long first4bytes)
 			{
 				if(VERBOSE3)
 					fprintf(stderr, "Note: faulty ID3v2 tag still clearing old data\n");
-				reset_id3(fr);
+				INT123_reset_id3(fr);
 			}
 		} else // No new data, but still there was a tag that invalidates old data.
 		{
 			if(VERBOSE3)
 				fprintf(stderr, "Note: empty ID3v2 clearing old data\n");
-			reset_id3(fr);
+			INT123_reset_id3(fr);
 		}
 tagparse_cleanup:
 		/* Get rid of stored raw data that should not be kept. */
