@@ -9,14 +9,10 @@
 #ifndef _MPG123_MODULE_H_
 #define _MPG123_MODULE_H_
 
-#ifdef HAVE_LTDL
-#include <ltdl.h>
-#endif
-
 #include "out123.h"
 
 /* TODO: put that into out123_int.h instead? */
-#define MPG123_MODULE_API_VERSION		(2)
+#define MPG123_MODULE_API_VERSION		(3)
 
 /* The full structure is delared in audio.h */
 struct audio_output_struct;
@@ -28,11 +24,7 @@ typedef struct mpg123_module_struct {
 	const char* description;					/* description of what the module does */
 	const char* revision;						/* source code revision */
 	
-#ifdef HAVE_LTDL
-	lt_dlhandle handle;							/* ltdl handle - set by open_module */
-#else
-	void* handle;
-#endif
+	void* handle; /* dynamic loader handle */
 
 	/* Initialisers - set to NULL if unsupported by module */
 	int (*init_output)(out123_handle *ao);		/* audio output - returns 0 on success */
@@ -43,8 +35,10 @@ typedef struct mpg123_module_struct {
 
 /* ------ Declarations from "module.c" ------ */
 
-mpg123_module_t* open_module(const char* type, const char* name, int verbose);
-void close_module(mpg123_module_t* module, int verbose);
-int list_modules(const char *type, char ***names, char ***descr, int verbose);
+mpg123_module_t* INT123_open_module( const char* type, const char* name, int verbose
+,	const char* bindir );
+void INT123_close_module(mpg123_module_t* module, int verbose);
+int INT123_list_modules( const char *type, char ***names, char ***descr, int verbose
+,	const char* bindir );
 
 #endif
