@@ -9,7 +9,7 @@
 */
 
 
-#include "out123_int.h"
+#include "../out123_int.h"
 
 /* has been around since at least 10.4 */
 #include <AvailabilityMacros.h>
@@ -44,9 +44,9 @@
 
 /* Including the sfifo code locally, to avoid module linkage issues. */
 #define SFIFO_STATIC
-#include "sfifo.c"
+#include "../sfifo.c"
 
-#include "debug.h"
+#include "../../common/debug.h"
 
 /* Duration of the ring buffer in seconds.
    Is that all that there is to tunable latency?
