@@ -6,10 +6,10 @@
 	initially written by Michael Hipp
 */
 
-#include "out123_int.h"
+#include "../out123_int.h"
 #include <fcntl.h>
 #include <sys/audio.h>
-#include "debug.h"
+#include "../../common/debug.h"
 
 
 static int set_rate(out123_handle *ao)
