@@ -6,7 +6,7 @@
 	initially written by Michael Hipp
 */
 
-#include "out123_int.h"
+#include "../out123_int.h"
 
 #include <sys/ioctl.h>
 #include <fcntl.h>
@@ -39,7 +39,7 @@
 # endif
 #endif
 
-#include "debug.h"
+#include "../../common/debug.h"
 
 struct oss_stuff
 {
@@ -312,7 +312,7 @@ mpg123_module_t mpg123_output_module_info = {
 	/* api_version */	MPG123_MODULE_API_VERSION,
 	/* name */			"oss",
 	/* description */	"Output audio using OSS",
-	/* revision */		"$Rev: 4021 $",
+	/* revision */		"$Rev: 5386 $",
 	/* handle */		NULL,
 	
 	/* init_output */	init_oss,
