@@ -1,7 +1,7 @@
 /*
 	playlist: playlist logic
 
-	copyright 1995-2020 by the mpg123 project - free software under the terms of the LGPL 2.1
+	copyright 1995-2023 by the mpg123 project - free software under the terms of the LGPL 2.1
 	see COPYING and AUTHORS files in distribution or http://mpg123.org
 	initially written by Michael Hipp, outsourced/reorganized by Thomas Orgis
 
@@ -22,7 +22,7 @@
 #include "local.h"
 #include "metaprint.h"
 #include <time.h> /* For srand(). */
-#include "debug.h"
+#include "common/debug.h"
 
 #ifdef HAVE_RANDOM
 #define RAND random
@@ -34,6 +34,14 @@
 
 enum playlist_type { UNKNOWN = 0, M3U, PLS, NO_LIST };
 
+enum playflag
+{
+	PL_IS_UTF8 = 1 // if we really know the contents are UTF-8-encooded
+,	PL_HIT_END = 2
+,	PL_STDIN_USED = 4 // If the playlist itself or an input file was '-' (stdin not usable for terminal.).
+,	PL_NO_RANDOM = 8
+};
+
 typedef struct listitem
 {
 	char* url; /* the filename */
@@ -56,10 +64,7 @@ typedef struct playlist_struct
 	mpg123_string linebuf;
 	mpg123_string dir;
 	enum playlist_type type;
-	int is_utf8; /* if we really know the contents are UTF-8-encooded */
-	int hit_end;
-	// If the playlist itself or an input file was '-' (stdin not usable for terminal.).
-	int stdin_used;
+	unsigned int flags;
 } playlist_struct;
 
 /* one global instance... add a pointer to this to every function definition and you have OO-style... */
@@ -97,7 +102,7 @@ void prepare_playlist(int argc, char** argv, int args_utf8, int *is_utf8)
 	mpg123_free_string(&pl.linebuf);
 	mpg123_free_string(&pl.dir);
 	if(is_utf8)
-		*is_utf8 = pl.is_utf8;
+		*is_utf8 = (pl.flags & PL_IS_UTF8) != 0;
 }
 
 /* Return a random number >= 0 and < n */
@@ -142,9 +147,9 @@ char *get_next_file(void)
 	}
 	else
 	{
-		/* Handle looping first, but only if there is a random track selection
-		   presently active (see playlist_jump() for interaction). */
-		if(!(pl.num && ((pl.loop > 0 && --pl.loop) || pl.loop < 0)))
+		// Handle looping first, but only if there is a random track selection
+		// Also applies to continue mode.
+		if(!(pl.num && ((pl.loop > 0 && --pl.loop) || pl.loop < 0)) && !(pl.flags & PL_NO_RANDOM))
 		{
 			/* Randomly select the next track. */
 			do /* limiting randomness: don't repeat too early */
@@ -157,6 +162,7 @@ char *get_next_file(void)
 
 		newitem = &pl.list[pl.pos];
 		pl.num = pl.pos+1;
+		pl.flags &= ~PL_NO_RANDOM; // The random blocking works only once.
 	}
 
 	/* "-" is STDIN, "" is dumb, NULL is nothing */
@@ -168,7 +174,7 @@ char *get_next_file(void)
 	}
 	else
 	{
-		pl.hit_end = TRUE;
+		pl.flags |= PL_HIT_END;
 		return NULL;
 	}
 }
@@ -179,7 +185,7 @@ size_t playlist_pos(size_t *total, long *loop)
 		*total = pl.fill;
 	if(loop)
 		*loop = pl.loop;
-	return pl.hit_end ? pl.fill+1 : pl.num;
+	return pl.flags & PL_HIT_END ? pl.fill+1 : pl.num;
 }
 
 void playlist_jump(mpg123_ssize_t incr)
@@ -190,7 +196,7 @@ void playlist_jump(mpg123_ssize_t incr)
 	/* Straight or shuffled lists can be jumped around in. */
 	if(pl.fill && param.shuffle < 2)
 	{
-		debug3("jump %"SIZE_P" (%ld) + %"SSIZE_P, (size_p)pl.pos, pl.loop, (ssize_p)incr);
+		debug3("jump %zu (%ld) + %" PRIiMAX, pl.pos, pl.loop, (intmax_t)incr);
 		if(pl.pos)
 			--pl.pos;
 		/* Now we're at the _current_ position. */
@@ -203,7 +209,7 @@ void playlist_jump(mpg123_ssize_t incr)
 			else
 				pl.pos += off;
 		}
-		debug2("jumped %"SIZE_P" (%ld)", (size_p)pl.pos, pl.loop);
+		debug2("jumped %zu (%ld)", pl.pos, pl.loop);
 	}
 }
 
@@ -286,23 +292,23 @@ static void init_playlist(void)
 	pl.fill = 0;
 	pl.pos = 0;
 	pl.num = 0;
-	if(APPFLAG(MPG123APP_CONTINUE) && param.listentry > 0)
-	pl.pos = param.listentry - 1;
-
 	pl.list = NULL;
 	pl.alloc_step = 10;
 	mpg123_init_string(&pl.dir);
 	mpg123_init_string(&pl.linebuf);
 	pl.type = UNKNOWN;
-	pl.is_utf8 = FALSE;
-	pl.hit_end = FALSE;
+	pl.flags = 0;
 	pl.loop = param.loop;
-	pl.stdin_used = FALSE;
+	if(APPFLAG(MPG123APP_CONTINUE) && param.listentry > 0)
+	{
+		pl.pos = param.listentry - 1;
+		pl.flags |= PL_NO_RANDOM; // Skip random selection for first track.
+	}
 }
 
-int playlist_stdin()
+int playlist_stdin(void)
 {
-	return pl.stdin_used;
+	return (pl.flags & PL_STDIN_USED) != 0;
 }
 
 /*
@@ -314,7 +320,10 @@ static int add_next_file (int argc, char *argv[], int args_utf8)
 {
 	int firstline = 0;
 
-	pl.is_utf8 = args_utf8;
+	if(args_utf8)
+		pl.flags |= PL_IS_UTF8;
+	else
+		pl.flags &= ~PL_IS_UTF8;
 
 	/* hack for url that has been detected as track, not playlist */
 	if(pl.type == NO_LIST) return 0;
@@ -343,7 +352,7 @@ static int add_next_file (int argc, char *argv[], int args_utf8)
 	if (param.listname || pl.file)
 	{
 		size_t line_offset = 0;
-		pl.is_utf8 = 0; // Playlist files in env encoding (HTTP lists should be ASCII-clean).
+		pl.flags &= ~PL_IS_UTF8; // Playlist files in env encoding (HTTP lists should be ASCII-clean).
 		if(!pl.file)
 		{
 			pl.file = stream_open(param.listname);
@@ -352,7 +361,7 @@ static int add_next_file (int argc, char *argv[], int args_utf8)
 				firstline = 1; /* just opened */
 				if(pl.file->fd == STDIN_FILENO)
 				{
-					pl.stdin_used = TRUE;
+					pl.flags |= PL_STDIN_USED;
 					param.listname = NULL;
 				}
 			}
@@ -393,7 +402,7 @@ static int add_next_file (int argc, char *argv[], int args_utf8)
 							}
 						}
 						char *ptmp = NULL;
-						outstr(&ptmp, pl.file->htd.content_type.p, 0, stderr_is_term);
+						outstr(&ptmp, pl.file->htd.content_type.p, 1, stderr_is_term);
 						error1( "Unknown playlist MIME type %s; maybe "PACKAGE_NAME
 							" can support it in future if you report this to the maintainer."
 						,	PSTR(ptmp) );
@@ -671,7 +680,7 @@ static int add_to_playlist(char* new_entry, char freeit)
 	if(pl.fill < pl.size)
 	{
 		if(!strcmp(new_entry, "-") || !strcmp(new_entry, "/dev/stdin"))
-			pl.stdin_used = TRUE;
+			pl.flags |= PL_STDIN_USED;
 		pl.list[pl.fill].freeit = freeit;
 		pl.list[pl.fill].url = new_entry;
 		pl.list[pl.fill].playcount = 0;
