@@ -12,6 +12,8 @@
 
 /* create playlist from argv including reading of playlist file */
 void prepare_playlist(int argc, char** argv, int args_utf8, int *is_utf8);
+/* Return TRUE if standard put is used up by the playlist. */
+int playlist_stdin(void);
 /* returns the next url to play or NULL when there is none left */
 char *get_next_file(void);
 /* Get current track number, optionally the total count and loop counter. */
@@ -21,7 +23,7 @@ void free_playlist(void);
 /* Print out the playlist, with optional position indicator. */
 void print_playlist(FILE* out, int showpos);
 /* This prepares a jump to be executed on next get_next_file(). */
-void playlist_jump(ssize_t incr);
+void playlist_jump(mpg123_ssize_t incr);
 /* Aim for the next directory (just trigger next track for random play). */
 void playlist_next_dir(void);
 /* Same for previous one. */
